﻿/*
 *  Caching is a meant as a non-web alternative to the somewhat similar HttpCache.
 *  Copyright (C) 2009 Steffen Skov

 *  This file is part of Caching.

 *  Caching is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.

 *  Caching is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.

 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Caching.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;

namespace Ckode.Caching
{
    internal class CacheItem<TValue>
    {
        private TValue value;
        internal DateTime AbsoluteExpiration { get; private set; }
        private ExpirationType expirationType;
        private TimeSpan expirationTime;

        public CacheItem(TValue value, ExpirationType expirationType, TimeSpan expirationTime)
        {
            this.value = value;
            this.expirationType = expirationType;
            this.expirationTime = expirationTime;
            AbsoluteExpiration = DateTime.Now.Add(expirationTime);
        }

        public void ExtendExpirationIfSliding()
        {
            if (expirationType == ExpirationType.SlidingExpiration)
                AbsoluteExpiration = DateTime.Now.Add(expirationTime);
        }

        public bool IsExpired()
        {
            return DateTime.Now > AbsoluteExpiration;
        }

        public TValue Value
        {
            get
            {
                return value;
            }
        }
    }
}
